pub enum MonitorEvent {
Connected(String),
Disconnected(String),
Finished(String),
RemoteError(String),
ClientError(String),
}Expand description
Monitor event types that can be returned by pop()
Variants
Connected(String)
Connection event (when maskConnected(true) is set)
Disconnected(String)
Disconnection event (when maskDisconnected(true) is set)
Finished(String)
Finished event (when maskDisconnected(true) is set). Subscription has completed normally and no more events will ever be received.
RemoteError(String)
Remote error event from server
ClientError(String)
Standard client side error. Catchs std::exception for client side failures.